==> 0.0.63.tar.gz: lib/widgets/src/text_input/input.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class CardInput extends StatefulWidget {
  const CardInput({
    Key? key,
    this.maxLines = 5,
    this.maxLength = 50,
    this.enable = true,
    this.defalutValue,
    this.hintText,
    this.onChange,
    this.textStyle,
    this.margin,
    this.contentPadding,
    this.height,
    this.decoration,
    this.inputDecoration,
  }) : super(key: key);
  final int maxLines;
  final int maxLength;
  final bool enable;
  final String? defalutValue;
  final String? hintText;
  final Function(String)? onChange;
  final TextStyle? textStyle;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? contentPadding;
  final double? height;
  final Decoration? decoration;
  final InputDecoration? inputDecoration;

  @override
  State<CardInput> createState() => _CardInputState();
}

class _CardInputState extends State<CardInput> {
  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController(text: widget.defalutValue)
      ..addListener(() {
        widget.onChange?.call(controller.text);
      });
  }

  @override
  void didUpdateWidget(CardInput oldWidget) {
    if (oldWidget.defalutValue != widget.defalutValue) {
      controller = TextEditingController(text: widget.defalutValue)
        ..addListener(() {
          widget.onChange?.call(controller.text);
        });
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: widget.margin ?? EdgeInsets.only(top: 0.h),
        height: widget.height,
        constraints: widget.height == null ? BoxConstraints(minHeight: 48.h) : null,
        decoration: widget.decoration,
        child: TextField(
          controller: controller,
          enabled: widget.enable,
          minLines: 1,
          maxLines: widget.maxLines,
          decoration: widget.inputDecoration ?? InputDecoration(
            contentPadding: widget.contentPadding ?? EdgeInsets.symmetric(horizontal: 8.w, vertical: 16.h),
            fillColor: const Color(0xfff7f8fa),
            filled: true,
            enabledBorder: OutlineInputBorder(borderSide: const BorderSide(color: Color(0x00FF0000)), borderRadius: BorderRadius.all(Radius.circular(4.r))),
            hintText: widget.hintText ?? '请输入',
            hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 16.sp),
            focusedBorder: OutlineInputBorder(borderSide: const BorderSide(color: Color(0x00000000)), borderRadius: BorderRadius.all(Radius.circular(4.r))),
          ),
          style: widget.textStyle,
          inputFormatters: <TextInputFormatter>[
            LengthLimitingTextInputFormatter(widget.maxLength) //限制长度
          ],
        ));
  }

  @override
  void dispose() {
    super.dispose();
    controller.dispose();
  }
}

class CardInputExc extends StatefulWidget {
  const CardInputExc({
    Key? key,
    this.maxLines = 5,
    this.maxLength = 50,
    this.enable = true,
    this.defalutValue,
    this.hintText,
    this.onChange,
    this.textStyle,
    this.margin,
    this.contentPadding,
    this.decoration,
  }) : super(key: key);
  final int maxLines;
  final int maxLength;
  final bool enable;
  final String? defalutValue;
  final String? hintText;
  final Function(String)? onChange;
  final TextStyle? textStyle;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? contentPadding;
  final Decoration? decoration;

  @override
  State<CardInputExc> createState() => _CardInputStateExc();
}

class _CardInputStateExc extends State<CardInputExc> {
  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController(text: widget.defalutValue)
      ..addListener(() {
        widget.onChange?.call(controller.text);
      });
  }

  @override
  void didUpdateWidget(CardInputExc oldWidget) {
    if (oldWidget.defalutValue != widget.defalutValue) {
      controller = TextEditingController(text: widget.defalutValue)
        ..addListener(() {
          widget.onChange?.call(controller.text);
        });
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: widget.margin ?? EdgeInsets.only(top: 0.h),
        decoration: widget.decoration,
        child: TextField(
          controller: controller,
          enabled: widget.enable,
          minLines: 1,
          maxLines: widget.maxLines,
          decoration: InputDecoration(
            contentPadding: widget.contentPadding ?? EdgeInsets.symmetric(horizontal: 8.w, vertical: 16.h),
            border: InputBorder.none,
            hintText: widget.hintText ?? '请输入',
          ),
          style: widget.textStyle,
          inputFormatters: <TextInputFormatter>[
            LengthLimitingTextInputFormatter(widget.maxLength) //限制长度
          ],
        ));
  }

  @override
  void dispose() {
    super.dispose();
    controller.dispose();
  }
}

class PageInput extends StatelessWidget {
  const PageInput({Key? key, required this.maxLength, required this.controller, this.hint, this.height = 260}) : super(key: key);

  final int maxLength;
  final TextEditingController controller;
  final String? hint;
  final int height;

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.bottomRight,
      children: [
        Container(
            height: height.h,
            decoration: const BoxDecoration(color: Color(0xfff7f8fa)),
            child: TextField(
              controller: controller,
              minLines: 1,
              maxLines: null,
              textInputAction: TextInputAction.done,
              decoration: InputDecoration(
                contentPadding: EdgeInsets.symmetric(horizontal: 8.w),
                fillColor: const Color(0xfff7f8fa),
                filled: true,
                enabledBorder: const OutlineInputBorder(borderSide: BorderSide(color: Color(0x00FF0000)), borderRadius: BorderRadius.all(Radius.circular(4))),
                hintText: hint ?? '请输入',
                focusedBorder: const OutlineInputBorder(borderSide: BorderSide(color: Color(0x00000000)), borderRadius: BorderRadius.all(Radius.circular(4))),
              ),
              inputFormatters: <TextInputFormatter>[
                LengthLimitingTextInputFormatter(maxLength) //限制长度
              ],
            )),
        Padding(
            padding: EdgeInsets.only(right: 20.w, bottom: 18.h),
            child: Text(
              "${controller.text.length}/$maxLength",
              style: const TextStyle(color: Color(0xffC8C9CC)),
            ))
      ],
    );
  }
}

==> 0.0.71.tar.gz: lib/widgets/src/text_input/input.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class CardInput extends StatefulWidget {
  const CardInput({
    Key? key,
    this.maxLines = 5,
    this.maxLength = 50,
    this.enable = true,
    this.defalutValue,
    this.hintText,
    this.onChange,
    this.textStyle,
    this.margin,
    this.contentPadding,
    this.height,
    this.decoration,
    this.inputDecoration,
    this.onDispose,
    this.onFocusChange,
  }) : super(key: key);
  final int maxLines;
  final int maxLength;
  final bool enable;
  final String? defalutValue;
  final String? hintText;
  final Function(String)? onChange;
  final TextStyle? textStyle;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? contentPadding;
  final double? height;
  final Decoration? decoration;
  final InputDecoration? inputDecoration;
  final Function()? onDispose;
  final Function(bool)? onFocusChange;

  @override
  State<CardInput> createState() => _CardInputState();
}

class _CardInputState extends State<CardInput> {
  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController(text: widget.defalutValue)
      ..addListener(() {
        widget.onChange?.call(controller.text);
      });
  }

  @override
  void didUpdateWidget(CardInput oldWidget) {
    if (oldWidget.defalutValue != widget.defalutValue) {
      TextSelection position = controller.selection.copyWith();
      controller = TextEditingController(text: widget.defalutValue);
      if (controller.isSelectionWithinTextBounds(position)) {
        controller.selection = position;
      }
      controller.addListener(() {
        widget.onChange?.call(controller.text);
      });
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  void dispose() {
    controller.dispose();
    widget.onDispose?.call();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Focus(
      onFocusChange: ((value) {
        widget.onFocusChange?.call(value);
      }),
      child: Container(
        margin: widget.margin ?? EdgeInsets.only(top: 0.h),
        height: widget.height,
        constraints: widget.height == null ? BoxConstraints(minHeight: 48.h) : null,
        decoration: widget.decoration,
        child: TextField(
          controller: controller,
          enabled: widget.enable,
          minLines: 1,
          maxLines: widget.maxLines,
          decoration: widget.inputDecoration ??
              InputDecoration(
                contentPadding: widget.contentPadding ?? EdgeInsets.symmetric(horizontal: 8.w, vertical: 16.h),
                fillColor: const Color(0xfff7f8fa),
                filled: true,
                enabledBorder: OutlineInputBorder(borderSide: const BorderSide(color: Color(0x00FF0000)), borderRadius: BorderRadius.all(Radius.circular(4.r))),
                hintText: widget.hintText ?? '请输入',
                hintStyle: TextStyle(color: const Color(0xff969799), fontSize: 16.sp),
                focusedBorder: OutlineInputBorder(borderSide: const BorderSide(color: Color(0x00000000)), borderRadius: BorderRadius.all(Radius.circular(4.r))),
              ),
          style: widget.textStyle,
          inputFormatters: <TextInputFormatter>[
            LengthLimitingTextInputFormatter(widget.maxLength) //限制长度
          ],
        ),
      ),
    );
  }
}

class CardInputExc extends StatefulWidget {
  const CardInputExc({
    Key? key,
    this.maxLines = 5,
    this.maxLength = 50,
    this.enable = true,
    this.defalutValue,
    this.hintText,
    this.onChange,
    this.textStyle,
    this.margin,
    this.contentPadding,
    this.decoration,
  }) : super(key: key);
  final int maxLines;
  final int maxLength;
  final bool enable;
  final String? defalutValue;
  final String? hintText;
  final Function(String)? onChange;
  final TextStyle? textStyle;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? contentPadding;
  final Decoration? decoration;

  @override
  State<CardInputExc> createState() => _CardInputStateExc();
}

class _CardInputStateExc extends State<CardInputExc> {
  late TextEditingController controller;

  @override
  void initState() {
    super.initState();
    controller = TextEditingController(text: widget.defalutValue)
      ..addListener(() {
        widget.onChange?.call(controller.text);
      });
  }

  @override
  void didUpdateWidget(CardInputExc oldWidget) {
    if (oldWidget.defalutValue != widget.defalutValue) {
      controller = TextEditingController(text: widget.defalutValue)
        ..addListener(() {
          widget.onChange?.call(controller.text);
        });
    }
    super.didUpdateWidget(oldWidget);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
        margin: widget.margin ?? EdgeInsets.only(top: 0.h),
        decoration: widget.decoration,
        child: TextField(
          controller: controller,
          enabled: widget.enable,
          minLines: 1,
          maxLines: widget.maxLines,
          decoration: InputDecoration(
            contentPadding: widget.contentPadding ?? EdgeInsets.symmetric(horizontal: 8.w, vertical: 16.h),
            border: InputBorder.none,
            hintText: widget.hintText ?? '请输入',
          ),
          style: widget.textStyle,
          inputFormatters: <TextInputFormatter>[
            LengthLimitingTextInputFormatter(widget.maxLength) //限制长度
          ],
        ));
  }

  @override
  void dispose() {
    super.dispose();
    controller.dispose();
  }
}

class PageInput extends StatelessWidget {
  const PageInput({Key? key, required this.maxLength, required this.controller, this.hint, this.height = 260}) : super(key: key);

  final int maxLength;
  final TextEditingController controller;
  final String? hint;
  final int height;

  @override
  Widget build(BuildContext context) {
    return Stack(
      alignment: Alignment.bottomRight,
      children: [
        Container(
            height: height.h,
            decoration: const BoxDecoration(color: Color(0xfff7f8fa)),
            child: TextField(
              controller: controller,
              minLines: 1,
              maxLines: null,
              textInputAction: TextInputAction.done,
              decoration: InputDecoration(
                contentPadding: EdgeInsets.symmetric(horizontal: 8.w),
                fillColor: const Color(0xfff7f8fa),
                filled: true,
                enabledBorder: const OutlineInputBorder(borderSide: BorderSide(color: Color(0x00FF0000)), borderRadius: BorderRadius.all(Radius.circular(4))),
                hintText: hint ?? '请输入',
                focusedBorder: const OutlineInputBorder(borderSide: BorderSide(color: Color(0x00000000)), borderRadius: BorderRadius.all(Radius.circular(4))),
              ),
              inputFormatters: <TextInputFormatter>[
                LengthLimitingTextInputFormatter(maxLength) //限制长度
              ],
            )),
        Padding(
            padding: EdgeInsets.only(right: 20.w, bottom: 18.h),
            child: Text(
              "${controller.text.length}/$maxLength",
              style: const TextStyle(color: Color(0xffC8C9CC)),
            ))
      ],
    );
  }
}
